import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

@Component({
  selector: 'app-page-crm-image',
  standalone: true,
  imports: [CommonModule, FormsModule],
  templateUrl: './page-crm-image.html',
  styleUrls: ['./page-crm-image.scss']
})
export class PageCrmImage {
  // 表单数据
  clientId = '';
  clientName = '';
  chatData = '';
  searchTerm = '';
  reportName = '';
  
  // 弹窗控制
  showBaseReportModal = false;
  showChatDetailModal = false;
  showAnalysisResultModal = false;
  
  // 当前日期
  currentDate = new Date();
  
  // 客户数据
  clientType = '企业客户';
  
  // 聊天记录详情
  chatDetail = {
    date: '2023-07-15 14:30',
    content: '客户表示对新产品很感兴趣，询问了价格和功能细节，希望下周能安排演示。'
  };
  
  // 分析结果
  analysisResult = {
    gender: '男',
    age: '35-40岁',
    job: 'IT经理',
    psychology: '理性决策型',
    consumption: '注重性价比',
    needs: '需要高效解决方案'
  };
  
  // 客户列表
  clients = [
    { id: 'C1001', name: '张明远', type: '企业客户', date: '06-28' },
    { id: 'P2003', name: '李思琪', type: '个人客户', date: '06-27' },
    { id: 'C1002', name: '王建国', type: '企业客户', date: '06-25' },
    { id: 'P2004', name: '陈晓薇', type: '个人客户', date: '06-24' }
  ];

  // 推荐数据
  recommendations = [
    {
      icon: 'fas fa-user-friends',
      title: '相似客户推荐',
      content: '根据张明远的画像特征，发现3位相似客户，沟通策略可复用率85%',
      tag: '高匹配度',
      buttonText: '查看客户',
      iconColor: 'rgba(74, 143, 231, 0.15)',
      iconTextColor: '#4a8fe7'
    },
    {
      icon: 'fas fa-clock',
      title: '最佳接触时机',
      content: '李思琪的下次最佳联系时间：明天上午10:00-11:30，接通率预测92%',
      tag: '高接通率',
      buttonText: '加入日程',
      iconColor: 'rgba(94, 114, 228, 0.15)',
      iconTextColor: '#5e72e4'
    }
  ];

  // 保存分析
  save() {
    if (!this.clientId || !this.clientName || !this.chatData) {
      alert('请填写完整的客户信息和聊天记录');
      return;
    }
    this.showBaseReportModal = true;
  }

  // 开始分析
  analyze() {
    if (!this.clientId || !this.clientName || !this.chatData) {
      alert('请填写完整的客户信息和聊天记录');
      return;
    }
    alert(`开始分析客户 ${this.clientName} (${this.clientId}) 的聊天记录...`);
  }

  // 打开聊天详情弹窗
  openChatDetailModal() {
    this.showBaseReportModal = false;
    this.showChatDetailModal = true;
  }

  // 打开分析结果弹窗
  openAnalysisResultModal() {
    this.showBaseReportModal = false;
    this.showAnalysisResultModal = true;
  }

  // 打开推荐策略弹窗
  openStrategyModal() {
    alert('推荐策略功能开发中...');
  }

  // 返回基础弹窗
  backToBaseModal() {
    this.showChatDetailModal = false;
    this.showAnalysisResultModal = false;
    this.showBaseReportModal = true;
  }

  // 关闭所有弹窗
  closeModal() {
    this.showBaseReportModal = false;
    this.showChatDetailModal = false;
    this.showAnalysisResultModal = false;
  }

  // 客户点击事件
  onClientClick(client: any) {
    alert(`进入客户详情页：${client.name}`);
  }
}